@@ -492,7 +492,7 @@ sub calcmaxdist {
     my $last  = $arr[-1];
     my %hash  = %{ calcdist( $first->[1], $last->[1], $factlevels_ref ) };
 
-    say $tee "raw max distance: " . dump( $hash{rawdist} );
+    "raw max distance: " . dump( $hash{rawdist} );
     return ( $hash{rawdist}, $first->[0], $last->[0] );
 }
 
@@ -1033,7 +1033,7 @@ sub wei {
     }
 
     unless ( ( $fulldo eq "$tight" ) and ( $count > 0 ) ) {
-        say $tee "Entering gradients' \%bank.";
+        "Entering gradients' \%bank.";
         my ( $bank_ref, $nears_ref ) = fillbank(
             \@arr__,       $minimumcertain, $minreq_forgrad,
             $maxdist,      $condweight,     \%factlevels,
@@ -1044,7 +1044,7 @@ sub wei {
         %bank  = %{$bank_ref};
         %nears = %{$nears_ref};
         %bank  = %{ clean( \%bank, $nfiltergrads, "principal", \@recedes ) };
-        say $tee "BANK DONE.";
+        "BANK DONE.";
     }
 
     sub mixbank {
@@ -1052,7 +1052,7 @@ sub wei {
         my %bank     = %{$bank_ref};
         my %weldbank = %{$weldbank_ref};
         my @parsws   = @{$parsws_ref};
-        say $tee "Mixing for welding " . dump(@parsws);
+        "Mixing for welding " . dump(@parsws);
         foreach my $trio ( keys %weldbank ) {
             unless ( $trio eq "" ) {
                 my @splits = split( "-", $trio );
@@ -1092,7 +1092,7 @@ sub wei {
                         @{ $bank{$trio}{orstring} },
                         @{ $weldbank{$trio}{orstring} }
                     );
-                    say $tee "weld $num.";
+                    "weld $num.";
                 }
             }
         }
@@ -1100,11 +1100,11 @@ sub wei {
     }
 
     unless ( ( scalar(@weldsprepared) == 0 ) ) {
-        say $tee "Entering gradients' bank for welding.";
+        "Entering gradients' bank for welding.";
         my $co = 0;
         foreach my $weldref (@weldaarrs) {
             my @parsws = @{ $parswelds[$co] };
-            say $tee "\@parsws: " . dump(@parsws);
+            "\@parsws: " . dump(@parsws);
             my @weldarr = @{$weldref};
             my @weldarr__;
             if (   ( $limit_checkdistgrads ne "" )
@@ -1156,7 +1156,7 @@ sub wei {
             %weldbank = %{ clean( \%weldbank, $nfiltergrads, "weld" ) };
 
             %bank = %{ mixbank( \%bank, \%weldbank, \@parsws ) };
-            say $tee "KEYS \%bank: " . ( keys %bank );
+            "KEYS \%bank: " . ( keys %bank );
 
             $co++;
         }
@@ -1378,16 +1378,16 @@ sub wei {
         return ( \%wand, \%nears );
     }
 
-    say $tee "GOING TO CREATE NEW POINTS.";
+    "GOING TO CREATE NEW POINTS.";
     my ( $wand_ref, $nears_ref ) = cyclearr(
         \@arr__, $minreq_forinclusion, $minreq_forgrad,
         \%bank,  \%factlevels,         $nfiltergrads,
         \@arrb,  $first0,              $last0,
         \%nears, $limitgrads,          $limitpoints
     );
-    say $tee "DONE.";
+    "DONE.";
     my %wand = %{$wand_ref};
-    say $tee "\nDONE.";
+    "\nDONE.";
     %nears = %{$nears_ref};
 
     my @limb0;
@@ -1933,7 +1933,7 @@ sub interlinear {
     if ( $blockelts_r ne "" ) { @blockelts = @{$blockelts_r}; }
 
     my @mode = adjustmode( $maxloops, \@mode );
-    say $tee "Opening $sourcefile";
+    "Opening $sourcefile";
     open( SOURCEFILE, "$sourcefile" ) or die;
     my @lines = <SOURCEFILE>;
     close SOURCEFILE;
@@ -1950,14 +1950,14 @@ sub interlinear {
 
     my @aarr = @{$aarr_ref};
 
-    say $tee "Checking factors and levels.";
+    "Checking factors and levels.";
     my %factlevels = %{ prepfactlev( \@aarr ) };
-    say $tee "Done.";
+    "Done.";
 
     my ($factlev_ref) = tellstepsize( \%factlevels, $lvconversion );
     my %factlev = %{$factlev_ref};
-    say $tee " \%factlev: " . dump(%factlev);
-    say $tee "Understood step sizes.";
+    " \%factlev: " . dump(%factlev);
+    "Understood step sizes.";
 
     my (@weldaarrs);
     if ( scalar(@weldsprepared) > 0 ) {
@@ -1998,7 +1998,7 @@ sub interlinear {
                 }
             }
             if ( $t == 0 ) {
-                say $tee "EXITING. DONE.";
+                "EXITING. DONE.";
                 printend( \@arr, $newfile, $optformat );
                 last;
             }
@@ -2039,7 +2039,7 @@ sub interlinear {
             %bank      = %{$bank_ref};
             %nears     = %{$nears_ref};
 
-            say $tee "THERE ARE "
+            "THERE ARE "
               . scalar(@limbo_wei)
               . " ITEMS IN THIS LOOP , NUMBER "
               . ( $count + 1 )
@@ -2052,7 +2052,7 @@ sub interlinear {
                 $overweightnearest, $parconcurrencies, $instconcurrencies,
                 $count,             \%factlev,         $maxdist
             );
-            say $tee "THERE ARE "
+            "THERE ARE "
               . scalar(@limbo_purelin)
               . " ITEMS IN THIS LOOP , NUMBER "
               . ( $count + 1 )
@@ -2063,7 +2063,7 @@ sub interlinear {
             @limbo_near =
               near( @arr, $nearrelaxlimit, $relaxmethod, $overweightnearest,
                 $nearconcurrencies, $count, \%factlev, $maxdist );
-            say $tee "THERE ARE "
+            "THERE ARE "
               . scalar(@limbo_near)
               . " ITEMS IN THIS LOOP, NUMBER "
               . ( $count + 1 )
@@ -2082,16 +2082,16 @@ sub interlinear {
             @limbo = @limbo_near;
         }
 
-        say $tee "MIXING THE ARRAY UPDATES "
+        "MIXING THE ARRAY UPDATES "
           . ( $count + 1 )
           . " for $sourcefile";
-        say $tee "THERE ARE "
+        "THERE ARE "
           . scalar(@limbo)
           . " ITEMS COMING OUT FROM THIS MIX "
           . ( $count + 1 );
 
         if ( ( scalar(@limbo) == 0 ) ) {
-            say $tee "EXITING.";
+            "EXITING.";
             printend( \@arr, $newfile, $optformat );
             last;
         }
@@ -2122,7 +2122,7 @@ sub interlinear {
             }
         }
         @arr2 = @arr;
-        say $tee "INSERTING THE ARRAY UPDATES "
+        "INSERTING THE ARRAY UPDATES "
           . ( $count + 1 )
           . " for $sourcefile";
         $count++;
