@@ -39,12 +39,12 @@ $ABSTRACT =
 sub parcoord3d {
     if ( not(@ARGV) ) {
         $tofile = $main::tofile;
-        say $tee "\n#Now in Sim::OPT::Takechance.\n";
+        "\n#Now in Sim::OPT::Takechance.\n";
         $configfile   = $main::configfile;
         @sweeps       = @main::sweeps;
         @sourcesweeps = @main::sourcesweeps;
         @varnumbers   = @main::varnumbers;
-        say $tee "dump(\@varnumbers): " . dump(@varnumbers);
+        "dump(\@varnumbers): " . dump(@varnumbers);
         @miditers  = @main::miditers;
         @rootnames = @main::rootnames;
         %vals      = %main::vals;
