@@ -55,7 +55,7 @@ sub newretrieve {
 
     $tee = new IO::Tee( \*STDOUT, ">>$tofile" );
 
-    say $tee "\n#Now in Sim::OPT::Report::newretrieve\n";
+    "\n#Now in Sim::OPT::Report::newretrieve\n";
 
     my %simtitles            = %main::simtitles;
     my %retrievedata         = %main::retrievedata;
@@ -78,24 +78,24 @@ sub newretrieve {
     my %dt = %{ $_[0] };
 
     my %dirfiles = %{ $dt{dirfiles} };
-    say $tee "HERE IN OPT SUB CALLBLOCK \%dirfiles: " . dump( \%dirfiles );
+    "HERE IN OPT SUB CALLBLOCK \%dirfiles: " . dump( \%dirfiles );
     my $resfile = $dt{resfile};
-    say $tee "HERE IN OPT SUB CALLBLOCK \$resfile: " . dump($resfile);
+    "HERE IN OPT SUB CALLBLOCK \$resfile: " . dump($resfile);
     my $flfile = $dt{flfile};
-    say $tee "HERE IN OPT SUB CALLBLOCK \$flfile: " . dump($flfile);
+    "HERE IN OPT SUB CALLBLOCK \$flfile: " . dump($flfile);
     my %vehicles = %{ $dt{vehicles} };
-    say $tee "HERE IN OPT SUB CALLBLOCK \%vehicles: " . dump( \%vehicles );
+    "HERE IN OPT SUB CALLBLOCK \%vehicles: " . dump( \%vehicles );
     my $precious = $dt{precious};
-    say $tee "HERE IN OPT SUB CALLBLOCK \$precious: " . dump($precious);
+    "HERE IN OPT SUB CALLBLOCK \$precious: " . dump($precious);
     my %inst = %{ $dt{inst} };
-    say $tee "1 HERE IN OPT SUB CALLBLOCK \%inst: " . dump( \%inst );
+    "1 HERE IN OPT SUB CALLBLOCK \%inst: " . dump( \%inst );
     my %dowhat        = %{ $dt{dowhat} };
     my $postprocessga = $dt{postprocessga};
 
     @{ $dirfiles{dones} } = uniq( @{ $dirfiles{dones} } );
     $inst_ref = Sim::OPT::filterinsts_wnames( \@{ $dirfiles{dones} }, \%inst );
     %inst = %{$inst_ref};
-    say $tee "1 HERE IN OPT SUB CALLBLOCK AFTER  \%inst: " . dump( \%inst );
+    "1 HERE IN OPT SUB CALLBLOCK AFTER  \%inst: " . dump( \%inst );
 
     my @simcases      = @{ $dirfiles{simcases} };
     my @simstruct     = @{ $dirfiles{simstruct} };
@@ -124,29 +124,29 @@ sub newretrieve {
     my %d = %{ $dt{instance} };
 
     my $countinstance = $d{instn};
-    say $tee "HERE IN REPORT \$countinstance: " . dump($countinstance);
+    "HERE IN REPORT \$countinstance: " . dump($countinstance);
 
     my $countcase = $d{countcase};
-    say $tee "HERE IN REPORT \$countcase: " . dump($countcase);
+    "HERE IN REPORT \$countcase: " . dump($countcase);
     my $countblock = $d{countblock};
-    say $tee "HERE IN REPORT \$countblock: " . dump($countblock);
+    "HERE IN REPORT \$countblock: " . dump($countblock);
     my %datastruc = %{ $d{datastruc} };
-    say $tee "HERE IN REPORT \%datastruc: " . dump( \%datastruc );
+    "HERE IN REPORT \%datastruc: " . dump( \%datastruc );
     my @varnumbers = @{ $d{varnumbers} };
     @varnumbers = Sim::OPT::washn(@varnumbers);
-    say $tee "HERE IN REPORT \@varnumbers: " . dump(@varnumbers);
+    "HERE IN REPORT \@varnumbers: " . dump(@varnumbers);
     my @miditers = @{ $d{miditers} };
     @miditers = Sim::OPT::washn(@miditers);
-    say $tee "HERE IN REPORT \@miditers: " . dump(@miditers);
+    "HERE IN REPORT \@miditers: " . dump(@miditers);
     my @sweeps = @{ $d{sweeps} };
-    say $tee "HERE IN REPORT \@sweeps: " . dump(@sweeps);
+    "HERE IN REPORT \@sweeps: " . dump(@sweeps);
 
     my $direction = ${ $dowhat{direction} }[$countcase][$countblock];
-    say $tee "HERE IN REPORT \$direction: " . dump($direction);
+    "HERE IN REPORT \$direction: " . dump($direction);
     my $precomputed = $dowhat{precomputed};
-    say $tee "HERE IN REPORT \$precomputed: " . dump($precomputed);
+    "HERE IN REPORT \$precomputed: " . dump($precomputed);
     my @takecolumns = @{ $dowhat{takecolumns} };
-    say $tee "HERE IN REPORT \@takecolumns: " . dump(@takecolumns);
+    "HERE IN REPORT \@takecolumns: " . dump(@takecolumns);
 
     my $skipfile   = $vals{skipfile};
     my $skipsim    = $vals{skipsim};
@@ -154,23 +154,23 @@ sub newretrieve {
     my %notecases;
 
     my @winneritems = @{ $d{winneritems} };
-    say $tee "HERE IN REPORT \@winneritems: " . dump(@winneritems);
+    "HERE IN REPORT \@winneritems: " . dump(@winneritems);
     my $countvar = $d{countvar};
-    say $tee "HERE IN REPORT \$countvar: " . dump($countvar);
+    "HERE IN REPORT \$countvar: " . dump($countvar);
     my $countstep = $d{countstep};
-    say $tee "HERE IN REPORT \$countstep: " . dump($countstep);
+    "HERE IN REPORT \$countstep: " . dump($countstep);
 
     my %to = %{ $d{to} };
-    say $tee "HERE IN REPORT \%to: " . dump(%to);
+    "HERE IN REPORT \%to: " . dump(%to);
     my $thisto = $to{to};
-    say $tee "\$thisto: $thisto";
+    "\$thisto: $thisto";
 
     my $cleanto = $inst{$thisto};
-    say $tee "\$cleanto: $cleanto";
+    "\$cleanto: $cleanto";
 
     my $origin = $d{origin};
     my $from   = $origin;
-    say $tee "HERE IN REPORT \$from: " . dump($from);
+    "HERE IN REPORT \$from: " . dump($from);
     my $is = $d{is};
 
     my $fire = $d{fire};
@@ -190,9 +190,9 @@ sub newretrieve {
 
     my $shortflfile = $flfile;
     $shortflfile =~ s/$thisto\/tmp\///;
-    say $tee "IN RETRIEVE: \$shortflfile: $shortflfile, \$flfile: $flfile";
+    "IN RETRIEVE: \$shortflfile: $shortflfile, \$flfile: $flfile";
 
-    say $tee "RELAUNCHED IN RETRIEVE WITH INST " . dump(%inst);
+    "RELAUNCHED IN RETRIEVE WITH INST " . dump(%inst);
 
     my $counttool = 1;
     while ( $counttool <= $numberof_simtools ) {
@@ -239,9 +239,9 @@ YYY
 ";
                 if ( ( $exeonfiles eq "y" ) or ( $dowhat{newretrieve} eq "y" ) )
                 {
-                    say $tee "#Retrieving temperature results.";
+                    "#Retrieving temperature results.";
                     print `$printthis`;
-                    say $tee "$printthis";
+                    "$printthis";
                 }
 
             }
@@ -286,9 +286,9 @@ $retfile
 ZZZ
 ";
                     if ( $exeonfilvalses eq "y" ) {
-                        say $tee "Retrieving comfort results.";
+                        "Retrieving comfort results.";
                         print `$printthis`;
-                        say $tee "$printthis";
+                        "$printthis";
                     }
                     print TOFILE "
 #Retrieving results for case "
@@ -360,15 +360,15 @@ TTT
 ";
                     }
                     else {
-                        say $tee "THERE ALREADY IS A RETFILE!";
+                        "THERE ALREADY IS A RETFILE!";
                     }
                 }
                 if ( ( $exeonfiles eq "y" ) or ( $dowhat{newretrieve} eq "y" ) )
                 {
 
-                    say $tee "#Retrieving $themereport results.";
+                    "#Retrieving $themereport results.";
                     print `$printthis`;
-                    say $tee "$printthis";
+                    "$printthis";
                 }
 
             }
@@ -415,9 +415,9 @@ TTT
                             or ( $dowhat{newretrieve} eq "y" ) )
                         {
 
-                            say $tee "#Retrieving $themereport results.";
+                            "#Retrieving $themereport results.";
                             print `$printthis`;
-                            say $tee "$printthis";
+                            "$printthis";
                         }
                     }
                     elsif ( $themereport eq "radabs" ) {
@@ -451,9 +451,9 @@ TTT
                             or ( $dowhat{newretrieve} eq "y" ) )
                         {
 
-                            say $tee "#Retrieving $themereport results.";
+                            "#Retrieving $themereport results.";
                             print `$printthis`;
-                            say $tee "$printthis";
+                            "$printthis";
                         }
                     }
                     elsif ( $themereport eq "airtemp" ) {
@@ -485,9 +485,9 @@ TTT
                             or ( $dowhat{newretrieve} eq "y" ) )
                         {
 
-                            say $tee "#Retrieving $themereport results.";
+                            "#Retrieving $themereport results.";
                             print `$printthis`;
-                            say $tee "$printthis";
+                            "$printthis";
                         }
                     }
                     elsif ( $themereport eq "radtemp" ) {
@@ -519,9 +519,9 @@ TTT
                             or ( $dowhat{newretrieve} eq "y" ) )
                         {
 
-                            say $tee "#Retrieving $themereport results.";
+                            "#Retrieving $themereport results.";
                             print `$printthis`;
-                            say $tee "$printthis";
+                            "$printthis";
                         }
                     }
                     elsif ( $themereport eq "restemp" ) {
@@ -553,7 +553,7 @@ TTT
                             or ( $dowhat{newretrieve} eq "y" ) )
                         {
 
-                            say $tee "#Retrieving $themereport results.";
+                            "#Retrieving $themereport results.";
                             print `$printthis`;
                         }
                     }
@@ -605,7 +605,7 @@ TTT
                                 my $reportdata_ref =
                                   $reportdata_ref_ref->[$countreport];
                                 @repdata = @$reportdata_ref;
-                                say $tee "HERE REPDATA: " . dump(@repdata);
+                                "HERE REPDATA: " . dump(@repdata);
 
                                 my $countitem = 0;
                                 foreach my $item (@repdata) {
@@ -680,7 +680,7 @@ TTT
                                     unless ( ( $dowhat{inactivateres} eq "y" )
                                         or ( -e $retfile ) )
                                     {
-                                        say $tee "#Retrieving results for case "
+                                        "#Retrieving results for case "
                                           . ( $countcase + 1 )
                                           . ", block "
                                           . ( $countblock + 1 )
@@ -937,13 +937,13 @@ sub newreport {
 
     $tee = new IO::Tee( \*STDOUT, ">>$tofile" );
 
-    say $tee "\nNow in Sim::OPT::Report::newreport\n";
+    "\nNow in Sim::OPT::Report::newreport\n";
 
     my %dt = %{ $_[0] };
 
     my %dirfiles = %{ $dt{dirfiles} };
     my $resfile  = $dt{resfile};
-    say $tee "BEGINNING REPORT: RESFILE $resfile";
+    "BEGINNING REPORT: RESFILE $resfile";
     my $flfile   = $dt{flfile};
     my %vehicles = %{ $dt{vehicles} };
     my $precious = $dt{precious};
@@ -1030,12 +1030,12 @@ sub newreport {
     my $direction   = ${ $dowhat{direction} }[$countcase][$countblock];
     my $precomputed = $dowhat{precomputed};
     my @takecolumns = @{ $dowhat{takecolumns} };
-    say $tee "HERE IN REPORT \@_: " . dump(@_);
+    "HERE IN REPORT \@_: " . dump(@_);
 
     my ( @repfilemem, @linecontent, @convey );
     $" = " ";
 
-    say $tee "#Processing reports for case "
+    "#Processing reports for case "
       . ( $countcase + 1 )
       . ", block "
       . ( $countblock + 1 )
@@ -1047,7 +1047,7 @@ sub newreport {
 
     my $divert;
     if ( $dirfiles{launching} eq "yes" ) {
-        say $tee "YES.";
+        "YES.";
         $divert = $repfile . ".revealnum.csv";
         open( DIVERT, ">>$divert" ) or die "Can't open $repfile $!";
     }
@@ -1066,10 +1066,10 @@ sub newreport {
     }
     my $signalnewinstance = 1;
 
-    say $tee "RELAUNCHED IN REPORT WITH INST " . dump(%inst);
-    say $tee "LOOKING FOR $repfile";
+    "RELAUNCHED IN REPORT WITH INST " . dump(%inst);
+    "LOOKING FOR $repfile";
 
-    say $tee "FIRE: $file";
+    "FIRE: $file";
 
     if (    ( ( $fire eq "yes" ) or ( $dowhat{reportbasics} eq "yes" ) )
         and ( $precomputed eq "" ) )
@@ -1136,7 +1136,7 @@ sub newreport {
                 {
                     %retitem = %$ret_ref;
                     my $retfile = $retitem{retfile};
-                    say $tee "IN REPORT 1 \$retfile $retfile";
+                    "IN REPORT 1 \$retfile $retfile";
                     my $reporttitle    = $retitem{reporttitle};
                     my $themereport    = $retitem{themereport};
                     my $semaphorego    = $retitem{semaphorego};
@@ -1164,14 +1164,14 @@ sub newreport {
                     my ( $semaphore1, $semaphore2 );
 
                     if ( -e $retfile ) {
-                        say $tee "#Inspecting results for case "
+                        "#Inspecting results for case "
                           . ( $countcase + 1 )
                           . ", block "
                           . ( $countblock + 1 )
                           . ", instance "
                           . ( $countinstance + 1 )
                           . ", file $retfile, to report $themereport.";
-                        say $tee "IN REPORT 2 \$retfile $retfile";
+                        "IN REPORT 2 \$retfile $retfile";
                         open( RETFILE, "$retfile" ) or die("$!");
                         my @lines = <RETFILE>;
                         close RETFILE;
@@ -1254,7 +1254,7 @@ sub newreport {
                                             );
                                         }
                                         else {
-                                            say $tee "NEWSTRATEGY";
+                                            "NEWSTRATEGY";
                                             push(
                                                 @{
                                                     $mergestruct[$countcase]
@@ -1277,7 +1277,7 @@ sub newreport {
                                             );
                                         }
                                         else {
-                                            say $tee "NEWSTRATEGY";
+                                            "NEWSTRATEGY";
                                             push(
                                                 @{
                                                     $mergestruct[$countcase]
@@ -1481,7 +1481,7 @@ sub newreport {
             if ( $dirfiles{launching} eq "yes" ) {
                 print DIVERT "\n";
             }
-            say $tee "#Reporting results for case "
+            "#Reporting results for case "
               . ( $countcase + 1 )
               . ", block "
               . ( $countblock + 1 )
@@ -1495,7 +1495,7 @@ sub newreport {
 
         my $touse = $is;
 
-        say $tee "TOUSE! $touse";
+        "TOUSE! $touse";
 
         my @box;
         foreach my $line (@precomputeds) {
@@ -1521,7 +1521,7 @@ sub newreport {
                 say DIVERT $el;
             }
         }
-        say $tee "#Reporting results for case "
+        "#Reporting results for case "
           . ( $countcase + 1 )
           . ", block "
           . ( $countblock + 1 )
@@ -1541,7 +1541,7 @@ sub newreport {
     if ( not( -e $repfile ) ) { die; }
 
     if ( $dirfiles{launching} eq "yes" ) {
-        say $tee "JUMPING";
+        "JUMPING";
         next;
     }
 
@@ -1551,7 +1551,7 @@ sub newreport {
     }
     else {
         if ( $precomputed eq "" ) {
-            say $tee "RETURNING $winbag[-1]";
+            "RETURNING $winbag[-1]";
             return ( $winbag[-1] );
         }
         else {
@@ -1559,7 +1559,7 @@ sub newreport {
             $winline =~ s/(\s+)$//;
             $winline =~ s/(,+)$//;
             my @elts = split( ",", $winline );
-            say $tee "RETURNING $elts[-1]";
+            "RETURNING $elts[-1]";
             return ( $elts[-1] );
         }
     }
