@@ -85,9 +85,9 @@ sub sim {
     }
 
     $tee = new IO::Tee( \*STDOUT, ">>$tofile" );
-    say $tee "\nNow in Sim::OPT::Sim.\n";
+    "\nNow in Sim::OPT::Sim.\n";
 
-    say $tee "RECEIVED DATA IN SIM: " . dump(@_);
+    "RECEIVED DATA IN SIM: " . dump(@_);
 
     my @simcases      = @{ $dirfiles{simcases} };
     my @simstruct     = @{ $dirfiles{simstruct} };
@@ -129,13 +129,13 @@ sub sim {
     my %notecases;
 
     my @trieds;
-    say $tee "HEARE IN SIM \@precedents: " . dump( \@precedents );
+    "HEARE IN SIM \@precedents: " . dump( \@precedents );
     foreach $prec_r (@precedents) {
         my %prec = %{$prec_r};
         my %to   = %{ $prec{to} };
         push( @trieds, $to{cleanto} );
     }
-    say $tee "HEARE IN SIM \@trieds: " . dump( \@trieds );
+    "HEARE IN SIM \@trieds: " . dump( \@trieds );
 
     my @allinstances = @instances;
     push( @allinstances, @precedents );
@@ -145,20 +145,20 @@ sub sim {
     my @container;
     foreach my $instance (@allinstances) {
         my %dt = %{$instance};
-        say $tee "HERE IN SIM \%dt: " . dump( \%dt );
+        "HERE IN SIM \%dt: " . dump( \%dt );
         my @winneritems = @{ $dt{winneritems} };
-        say $tee "HERE IN SIM \@winneritems: " . dump(@winneritems);
+        "HERE IN SIM \@winneritems: " . dump(@winneritems);
         my $countvar = $dt{countvar};
-        say $tee "HERE IN SIM \$countvar: " . dump($countvar);
+        "HERE IN SIM \$countvar: " . dump($countvar);
         my $countstep = $dt{countstep};
-        say $tee "HERE IN SIM \$countstep: " . dump($countstep);
+        "HERE IN SIM \$countstep: " . dump($countstep);
         my $c = $dt{c};
-        say $tee "HERE IN SIM \$c: " . dump($c);
+        "HERE IN SIM \$c: " . dump($c);
 
         my %to = %{ $dt{to} };
-        say $tee "HERE IN SIM \%to: " . dump( \%to );
+        "HERE IN SIM \%to: " . dump( \%to );
         my $instn = $dt{instn};
-        say $tee "HERE IN SIM \$instn: " . dump($instn);
+        "HERE IN SIM \$instn: " . dump($instn);
 
         my $origin = $dt{origin};
         my $from   = $origin;
@@ -166,15 +166,15 @@ sub sim {
         my $stamp  = $dt{stamp};
 
         my @blockelts = @{ $dt{blockelts} };
-        say $tee "HERE IN SIM \@blockelts: " . dump(@blockelts);
+        "HERE IN SIM \@blockelts: " . dump(@blockelts);
         my @blocks = @{ $dt{blocks} };
-        say $tee "HERE IN SIM \@blocks: " . dump(@blocks);
+        "HERE IN SIM \@blocks: " . dump(@blocks);
         my %varnums = %{ $dt{varnums} };
-        say $tee "HERE IN SIM \%varnums: " . dump( \%varnums );
+        "HERE IN SIM \%varnums: " . dump( \%varnums );
         my %mids = %{ $dt{mids} };
-        say $tee "HERE IN SIM \%mids: " . dump( \%mids );
+        "HERE IN SIM \%mids: " . dump( \%mids );
         my $countinstance = $dt{instn};
-        say $tee "HERE IN SIM \$countinstance: " . dump($countinstance);
+        "HERE IN SIM \$countinstance: " . dump($countinstance);
 
         my $fire   = $dt{fire};
         my $gaproc = $dt{gaproc};
@@ -195,7 +195,7 @@ sub sim {
 
         my $numberof_simtools = scalar( keys %{ $dowhat{simtools} } );
         my $simelt            = $to{crypto};
-        say $tee "SIMELT: $simelt";
+        "SIMELT: $simelt";
         my $shortsimelt = $simelt;
         $shortsimelt =~ s/$mypath\///;
         my ( $shortresfile, $shortflfile );
@@ -274,7 +274,7 @@ sub sim {
                                     or ( $postproc eq "yes" ) )
                                 {
                                     if ( $simnetwork eq "y" ) {
-                                        say $tee "#Simulating case "
+                                        "#Simulating case "
                                           . ( $countcase + 1 )
                                           . ", block "
                                           . ( $countblock + 1 )
@@ -302,7 +302,7 @@ y
 XXX
   ";
 
-                                        say $tee "#Simulating case "
+                                        "#Simulating case "
                                           . ( $countcase + 1 )
                                           . ", block "
                                           . ( $countblock + 1 )
@@ -313,7 +313,7 @@ XXX
                                         print OUTFILE "TWO, $resfile\n";
                                     }
                                     else {
-                                        say $tee "#Simulating case "
+                                        "#Simulating case "
                                           . ( $countcase + 1 )
                                           . ", block "
                                           . ( $countblock + 1 )
@@ -500,7 +500,7 @@ XXX
 `runenergyplus $templaunch $epwfile`;
                                         }
 
-                                        say $tee "#Simulating case "
+                                        "#Simulating case "
                                           . ( $countcase + 1 )
                                           . ", block "
                                           . ( $countblock + 1 )
@@ -516,9 +516,9 @@ XXX
                 $counttool++;
             }
         }
-        say $tee "IN SIM RESFILE $resfile";
+        "IN SIM RESFILE $resfile";
         if ( $dowhat{newretrieve} eq "y" ) {
-            say $tee "DOING 1";
+            "DOING 1";
             unless ( ( $postproc eq "yes" ) ) {
                 my @resultretrieve = Sim::OPT::Report::newretrieve(
                     {
@@ -540,7 +540,7 @@ XXX
         }
 
         if ( $dowhat{newreport} eq "y" ) {
-            say $tee "DOING 2";
+            "DOING 2";
             my @resultreport = Sim::OPT::Report::newreport(
                 {
                     instance => $instance,
@@ -567,7 +567,7 @@ XXX
     return ( \@simcases, \@simstruct, $dirfiles{repcases}, $dirfiles{repstruct},
         $dirfiles{mergestruct}, $dirfiles{mergecases}, $csim );
 
-    say $tee "LEAVING SIMULATION MODULE";
+    "LEAVING SIMULATION MODULE";
     close TOFILE;
     close OUTFILE;
 
