@@ -38,7 +38,7 @@ sub takechance {
     if ( not(@ARGV) ) {
         $tofile = $main::tofile;
         $tee = new IO::Tee( \*STDOUT, ">>$tofile" );
-        say $tee "\n#Now in Sim::OPT::Takechance.\n";
+        "\n#Now in Sim::OPT::Takechance.\n";
         $configfile   = $main::configfile;
         @sweeps       = @main::sweeps;
         @sourcesweeps = @main::sourcesweeps;
@@ -170,7 +170,7 @@ sub takechance {
                             chancegroup => [@chancerefs_alias]
                         }
                     );
-                    say $tee "dumpXX(INBUILD-AFTER\@pastsweepblocks): "
+                    "dumpXX(INBUILD-AFTER\@pastsweepblocks): "
                       . dump(@pastsweepblocks);
 
                     push( @caserefs_alias, [ $beginning, $blocklength ] );
@@ -204,13 +204,13 @@ sub takechance {
                     }
 
                     if ( not( $semaphore == 1 ) ) {
-                        say $tee "NOT HIT. \$countshuffle: $countshuffle.";
+                        "NOT HIT. \$countshuffle: $countshuffle.";
                         $countshuffle++;
                         &_shuffle_;
                     }
                     else {
                         return ( \@shuffledchanceres, \@shuffledchanceelms );
-                        say $tee "HIT. \$countshuffle: $countshuffle.";
+                        "HIT. \$countshuffle: $countshuffle.";
                     }
                 }
                 my @result = _shuffle_;
@@ -227,7 +227,7 @@ sub takechance {
                   \@chancerefs_alias;
                 my @thischance =
                   @{ $lab{$countcase}{$countbuild}{$countchance}{chance} };
-                say $tee "dump(OUTBUILD\%lab): " . dump(%lab);
+                "dump(OUTBUILD\%lab): " . dump(%lab);
 
                 my $countfirstline = 0;
 
@@ -573,11 +573,11 @@ sub takechance {
                             $counter++;
                         }
 
-                        say $tee "BEYOND AFTERCLEAN: \@resbunch: @resbunch";
+                        "BEYOND AFTERCLEAN: \@resbunch: @resbunch";
 
                         push( @resbunches, [@resbunch] );
 
-                        say $tee "BEYOND1 AFTERCLEAN  Dumper(\@resbunches:) "
+                        "BEYOND1 AFTERCLEAN  Dumper(\@resbunches:) "
                           . Dumper(@resbunches);
 
                         my @presentbunch = @{ $resbunches[0] };
@@ -597,7 +597,7 @@ sub takechance {
                             $countthis++;
                         }
 
-                        say $tee "BEYOND1 OUTSIDE AFTERCLEAN \@scores: @scores";
+                        "BEYOND1 OUTSIDE AFTERCLEAN \@scores: @scores";
 
                         $score = Sim::OPT::max(@scores);
                         my $newoccurrences = $activeblock - $score;
@@ -618,7 +618,7 @@ sub takechance {
                     }
 
                     my $urr = ( $n1_averageage * $novelty );
-                    say $tee "BEYOND2 \$urr-->: $urr";
+                    "BEYOND2 \$urr-->: $urr";
 
                     my $stddev = stddev(@finalbasket);
                     if ( $stddev == 0 ) { $stddev = 0.0001; }
@@ -815,26 +815,26 @@ sub takechance {
             }
             my @arr = pick($maxvalue);
             $beststruct = $arr[0];
-            say $tee "POST\$beststruct " . dump($beststruct);
+            "POST\$beststruct " . dump($beststruct);
             $bestchance = $arr[1];
-            say $tee "POST\$bestchance " . dump($bestchance);
+            "POST\$bestchance " . dump($bestchance);
 
-            say $tee "PRE\@blockrefs " . dump(@blockrefs);
+            "PRE\@blockrefs " . dump(@blockrefs);
             @blockrefs = @$beststruct;
-            say $tee "POST\@blockrefs " . dump(@blockrefs);
-            say $tee "PRE\@chancerefs " . dump(@chancerefs);
+            "POST\@blockrefs " . dump(@blockrefs);
+            "PRE\@chancerefs " . dump(@chancerefs);
             @chancerefs = @$bestchance;
-            say $tee "POST\@chancerefs " . dump(@chancerefs);
-            say $tee "\$res " . dump(%res);
+            "POST\@chancerefs " . dump(@chancerefs);
+            "\$res " . dump(%res);
             $chanceseed_[$countcase] = $bestchance;
-            say $tee "POST\@chanceseed_ " . Dumper(@chanceseed_);
+            "POST\@chanceseed_ " . Dumper(@chanceseed_);
             $caseseed_[$countcase] = $beststruct;
-            say $tee "POST\@caseseed_ " . Dumper(@caseseed_);
+            "POST\@caseseed_ " . Dumper(@caseseed_);
             @sweeps_ = Sim::OPT::fromopt_tosweep(
                 casegroup   => \@caseseed_,
                 chancegroup => \@chanceseed_
             );
-            say $tee "POST\@sweeps_ " . Dumper(@sweeps_);
+            "POST\@sweeps_ " . Dumper(@sweeps_);
             close TEST;
             close CASEFILE_PROV;
             close CHANCEFILE_PROV;
